[coreboot-gerrit] New patch to review for coreboot: 59951f8 console: conditionally include console in bootblock

Isaac Christensen (isaac.christensen@se-eng.com) gerrit at coreboot.org
Wed Aug 13 00:53:40 CEST 2014


Isaac Christensen (isaac.christensen at se-eng.com) just uploaded a new patch set to gerrit, which you can find at http://review.coreboot.org/6637

-gerrit

commit 59951f8c8b0b09e4444a987a86c9fd2391f61995
Author: Stefan Reinauer <reinauer at chromium.org>
Date:   Tue Sep 10 10:58:28 2013 -0700

    console: conditionally include console in bootblock
    
    Right now some console specific objects are included
    in the bootblock even if CONFIG_BOOTBLOCK_CONSOLE is
    disabled while others are not. Make all of them conditional
    and also fix a preprocessor misuse in bootblock_simple.c
    and a stray (useless) die() in the Exynos wakeup code that
    made inclusion of those files necessary.
    
    Change-Id: Ia7f9d17654466f199b0e13afbdc9e14c9706530f
    Signed-off-by: Stefan Reinauer <reinauer at google.com>
    Reviewed-on: https://chromium-review.googlesource.com/168772
    Reviewed-by: David Hendrix <dhendrix at chromium.org>
    (cherry picked from commit 855da1f07b52898c7edcaffe5baabe9d485bbd83)
    Signed-off-by: Isaac Christensen <isaac.christensen at se-eng.com>
---
 src/console/Makefile.inc            | 2 +-
 src/cpu/samsung/exynos5250/wakeup.c | 4 ++--
 src/cpu/samsung/exynos5420/wakeup.c | 4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/console/Makefile.inc b/src/console/Makefile.inc
index 435d704..c72c60b 100644
--- a/src/console/Makefile.inc
+++ b/src/console/Makefile.inc
@@ -13,7 +13,7 @@ romstage-y += die.c
 
 bootblock-$(CONFIG_BOOTBLOCK_CONSOLE) += vtxprintf.c printk.c
 bootblock-$(CONFIG_BOOTBLOCK_CONSOLE) += init.c console.c
-bootblock-y += die.c
+bootblock-$(CONFIG_BOOTBLOCK_CONSOLE) += die.c
 
 $(obj)/console/init.smm.o : $(obj)/build.h
 $(obj)/console/init.ramstage.o : $(obj)/build.h
diff --git a/src/cpu/samsung/exynos5250/wakeup.c b/src/cpu/samsung/exynos5250/wakeup.c
index 5764c83..02f2ccd 100644
--- a/src/cpu/samsung/exynos5250/wakeup.c
+++ b/src/cpu/samsung/exynos5250/wakeup.c
@@ -28,8 +28,8 @@ void wakeup(void)
 
 	power_init();  /* Ensure ps_hold_setup() for early wakeup. */
 	power_exit_wakeup();
-	/* Should never return. */
-	die("Failed to wake up.\n");
+	/* Should never return. If we do, reset. */
+	power_reset();
 }
 
 int get_wakeup_state(void)
diff --git a/src/cpu/samsung/exynos5420/wakeup.c b/src/cpu/samsung/exynos5420/wakeup.c
index af7ef73..9d3f065 100644
--- a/src/cpu/samsung/exynos5420/wakeup.c
+++ b/src/cpu/samsung/exynos5420/wakeup.c
@@ -31,8 +31,8 @@ void wakeup(void)
 	dcache_mmu_disable();
 	icache_invalidate_all();
 	power_exit_wakeup();
-	/* Should never return. */
-	die("Failed to wake up.\n");
+	/* Should never return. If we do, reset. */
+	power_reset();
 }
 
 int get_wakeup_state(void)



More information about the coreboot-gerrit mailing list